@@ -5,9 +5,7 @@
 #'
 #' The `by` argument is used to plot marginal predictions, that is, predictions made on the original data, but averaged by subgroups. This is analogous to using the `by` argument in the `predictions()` function.
 #'
-#' The `condition` argument is used to plot conditional predictions, that is, predictions made on a user-specified grid. This is analogous to using the `newdata` argument and `datagrid()` function in a `predictions()` call. 
-#' 
-#' All unspecified variables are held at their mean or mode. This includes grouping variables in mixed-effects models, so analysts who fit such models may want to specify the groups of interest using the `variables` argument, or supply model-specific arguments to compute population-level estimates. See details below.
+#' The `condition` argument is used to plot conditional predictions, that is, predictions made on a user-specified grid. This is analogous to using the `newdata` argument and `datagrid()` function in a `predictions()` call. All variables whose values are not specified explicitly are treated as usual by `datagrid()`, that is, they are held at their mean or mode (or rounded mean for integers). This includes grouping variables in mixed-effects models, so analysts who fit such models may want to specify the groups of interest using the `condition` argument, or supply model-specific arguments to compute population-level estimates. See details below.
 #' 
 #' See the "Plots" vignette and website for tutorials and information on how to customize plots:
 #'
@@ -52,7 +50,7 @@ plot_predictions <- function(model,
                              type = NULL,
                              vcov = NULL,
                              conf_level = 0.95,
-                             wts = NULL,
+                             wts = FALSE,
                              transform = NULL,
                              points = 0,
                              rug = FALSE,
@@ -76,8 +74,8 @@ plot_predictions <- function(model,
 
     # order of the first few paragraphs is important
     scall <- rlang::enquo(newdata)
-    newdata <- sanitize_newdata_call(scall, newdata, model)
-    if (!is.null(wts) && is.null(by)) {
+    newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
+    if (!isFALSE(wts) && is.null(by)) {
         insight::format_error("The `wts` argument requires a `by` argument.")
     }
     checkmate::assert_character(by, null.ok = TRUE)
@@ -190,13 +188,3 @@ plot_predictions <- function(model,
 
 
 
-#' `plot_predictions()` is an alias to `plot_predictions()`
-#'
-#' This alias is kept for backward compatibility.
-#' @inherit plot_predictions
-#' @keywords internal
-#' @export
-plot_cap <- function(...) {
-    insight::format_warning("This function has been renamed to `plot_predictions()`. The `plot_cap()` alias will be removed in the near future.")
-    plot_predictions(...)
-}
\ No newline at end of file
