@@ -5,9 +5,7 @@
 #'
 #' The `by` argument is used to plot marginal slopes, that is, slopes made on the original data, but averaged by subgroups. This is analogous to using the `by` argument in the `slopes()` function.
 #'
-#' The `condition` argument is used to plot conditional slopes, that is, slopes made on a user-specified grid. This is analogous to using the `newdata` argument and `datagrid()` function in a `slopes()` call.
-#' 
-#' All unspecified variables are held at their mean or mode. This includes grouping variables in mixed-effects models, so analysts who fit such models may want to specify the groups of interest using the `variables` argument, or supply model-specific arguments to compute population-level estimates. See details below.
+#' The `condition` argument is used to plot conditional slopes, that is, slopes computed on a user-specified grid. This is analogous to using the `newdata` argument and `datagrid()` function in a `slopes()` call. All variables whose values are not specified explicitly are treated as usual by `datagrid()`, that is, they are held at their mean or mode (or rounded mean for integers). This includes grouping variables in mixed-effects models, so analysts who fit such models may want to specify the groups of interest using the `condition` argument, or supply model-specific arguments to compute population-level estimates. See details below.
 
 #' See the "Plots" vignette and website for tutorials and information on how to customize plots:
 #'
@@ -53,7 +51,7 @@ plot_slopes <- function(model,
                         type = "response",
                         vcov = NULL,
                         conf_level = 0.95,
-                        wts = NULL,
+                        wts = FALSE,
                         slope = "dydx",
                         rug = FALSE,
                         gray = FALSE,
@@ -101,14 +99,3 @@ plot_slopes <- function(model,
     return(out)
 }
 
-
-#' `plot_slopes()` is an alias to `plot_slopes()`
-#'
-#' This alias is kept for backward compatibility.
-#' @inherit plot_predictions
-#' @keywords internal
-#' @export
-plot_cme <- function(...) {
-    insight::format_warning("This function has been renamed to `plot_slopes()`. The `plot_cme()` alias will be removed in the near future.")
-    plot_slopes(...)
-}
\ No newline at end of file
