@@ -30,6 +30,8 @@
 #' + [datagrid()] call to specify a custom grid of regressors. For example:
 #'   - `newdata = datagrid(cyl = c(4, 6))`: `cyl` variable equal to 4 and 6 and other regressors fixed at their means or modes.
 #'   - See the Examples section and the [datagrid()] documentation.
+#' + [subset()] call with a single argument to select a subset of the dataset used to fit the model, ex: `newdata = subset(treatment == 1)`
+#' + [dplyr::filter()] call with a single argument to select a subset of the dataset used to fit the model, ex: `newdata = filter(treatment == 1)`
 #' + string:
 #'   - "mean": Marginal Effects at the Mean. Slopes when each predictor is held at its mean or mode.
 #'   - "median": Marginal Effects at the Median. Slopes when each predictor is held at its median or mode.
@@ -60,15 +62,17 @@
 #' - "eydx": dY/dX * Y
 #' - "dyex": dY/dX / X
 #' - Y is the predicted value of the outcome; X is the observed value of the predictor.
-#' @param wts string or numeric: weights to use when computing average contrasts or slopes. These weights only affect the averaging in `avg_*()` or with the `by` argument, and not the unit-level estimates themselves. Internally, estimates and weights are passed to the `weighted.mean()` function.
+#' @param wts logical, string or numeric: weights to use when computing average predictions, contrasts or slopes. These weights only affect the averaging in `avg_*()` or with the `by` argument, and not unit-level estimates. See `?weighted.mean`
 #' + string: column name of the weights variable in `newdata`. When supplying a column name to `wts`, it is recommended to supply the original data (including the weights variable) explicitly to `newdata`.
 #' + numeric: vector of length equal to the number of rows in the original data or in `newdata` (if supplied).
-#' @param hypothesis specify a hypothesis test or custom contrast using a numeric value, vector, or matrix, a string, or a string formula.
+#' + FALSE: Equal weights.
+#' + TRUE: Extract weights from the fitted object with `insight::find_weights()` and use them when taking weighted averages of estimates. Warning: `newdata=datagrid()` returns a single average weight, which is equivalent to using `wts=FALSE`
+#' @param hypothesis specify a hypothesis test or custom contrast using a numeric value, vector, or matrix, a string, a string formula, or a function.
 #' + Numeric:
 #'   - Single value: the null hypothesis used in the computation of Z and p (before applying `transform`).
 #'   - Vector: Weights to compute a linear combination of (custom contrast between) estimates. Length equal to the number of rows generated by the same function call, but without the `hypothesis` argument.
 #'   - Matrix: Each column is a vector of weights, as describe above, used to compute a distinct linear combination of (contrast between) estimates. The column names of the matrix are used as labels in the output.
-#' + String formula to specify linear or non-linear hypothesis tests. If the `term` column uniquely identifies rows, terms can be used in the formula. Otherwise, use `b1`, `b2`, etc. to identify the position of each parameter. The `b*` wildcard can be used to test hypotheses on all estimates. Examples:
+#' + String formula to specify linear or non-linear hypothesis tests. If the `term` column uniquely identifies rows, terms can be used in the formula. Otherwise, use `b1`, `b2`, etc. to identify the position of each parameter. The `b*` wildcard can be used to test hypotheses on all estimates. If a named vector is used, the names are used as labels in the output. Examples:
 #'   - `hp = drat`
 #'   - `hp + drat = 12`
 #'   - `b1 + b2 + b3 = 0`
@@ -78,6 +82,11 @@
 #'   - "reference": differences between the estimates in each row and the estimate in the first row.
 #'   - "sequential": difference between an estimate and the estimate in the next row.
 #'   - "revpairwise", "revreference", "revsequential": inverse of the corresponding hypotheses, as described above.
+#' + Function:
+#'   - Accepts an argument `x`: object produced by a `marginaleffects` function or a data frame with column `rowid` and `estimate`
+#'   - Returns a data frame with columns `term` and `estimate` (mandatory) and `rowid` (optional).
+#'   - The function can also accept and operation on optional input arguments: `newdata`, `by`, `draws`.
+#'   - This function approach will not work for Bayesian models or with bootstrapping. In those cases, it is easy to use `posterior_draws()` to extract and manipulate the draws directly.
 #' + See the Examples section below and the vignette: https://marginaleffects.com/vignettes/hypothesis.html
 #' @param p_adjust Adjust p-values for multiple comparisons: "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", or "fdr". See [stats::p.adjust]
 #' @param df Degrees of freedom used to compute p values and confidence intervals. A single numeric value between 1 and `Inf`. When `df` is `Inf`, the normal distribution is used. When `df` is finite, the `t` distribution is used. See [insight::get_df] for a convenient function to extract degrees of freedom. Ex: `slopes(model, df = insight::get_df(model))`
@@ -98,7 +107,7 @@
 #' `marginaleffects` website). Available arguments can vary from model to
 #' model, depending on the range of supported arguments by each modeling
 #' package. See the "Model-Specific Arguments" section of the
-#' `?marginaleffects` documentation for a non-exhaustive list of available
+#' `?slopes` documentation for a non-exhaustive list of available
 #' arguments.
 #' @inheritParams comparisons
 #'
@@ -112,7 +121,9 @@
 #' @template bayesian
 #' @template equivalence
 #' @template type
+#' @template parallel
 #' @template references
+#' @template order_of_operations
 #'
 #' @return A `data.frame` with one row per observation (per term/group) and several columns:
 #' * `rowid`: row number of the `newdata` data frame
@@ -128,10 +139,8 @@
 #'
 #' See `?print.marginaleffects` for printing options.
 #'
-#' @examplesIf interactive()
+#' @examplesIf interactive() || isTRUE(Sys.getenv("R_DOC_BUILD") == "true")
 #' @examples
-#' \dontrun{
-#'
 #' # Unit-level (conditional) Marginal Effects
 #' mod <- glm(am ~ hp * wt, data = mtcars, family = binomial)
 #' mfx <- slopes(mod)
@@ -199,7 +208,6 @@
 #'     newdata = "mean",
 #'     hypothesis = lc)
 #' 
-#' }
 #' @export
 slopes <- function(model,
                    newdata = NULL,
@@ -209,7 +217,7 @@ slopes <- function(model,
                    vcov = TRUE,
                    conf_level = 0.95,
                    slope = "dydx",
-                   wts = NULL,
+                   wts = FALSE,
                    hypothesis = NULL,
                    equivalence = NULL,
                    p_adjust = NULL,
@@ -223,7 +231,7 @@ slopes <- function(model,
     # very early, before any use of newdata
     # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
     scall <- rlang::enquo(newdata)
-    newdata <- sanitize_newdata_call(scall, newdata, model)
+    newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
 
     # build call: match.call() doesn't work well in *apply()
     call_attr <- c(list(
@@ -304,27 +312,6 @@ slopes <- function(model,
 
 
 
-#' `marginaleffects()` is an alias to `slopes()`
-#'
-#' This alias is kept for backward compatibility and because some users may prefer that name.
-#'
-#' @inherit marginaleffects
-#' @keywords internal
-#' @export
-marginaleffects <- function(...) {
-    insight::format_warning("This function has been renamed to `slopes()`. The `marginaleffects()` alias will be removed in the near future.")
-    slopes(...)
-}
-
-
-#' `meffects()` is an alias to `slopes()`
-#'
-#' This alias is kept for backward compatibility and because some users may prefer that name.
-#' @inherit marginaleffects
-#' @keywords internal
-#' @export
-meffects <- marginaleffects
-
 
 #' Average slopes (aka Average partial derivatives, marginal effects, or trends)
 #' @describeIn slopes Average slopes
@@ -338,7 +325,7 @@ avg_slopes <- function(model,
                        vcov = TRUE,
                        conf_level = 0.95,
                        slope = "dydx",
-                       wts = NULL,
+                       wts = FALSE,
                        hypothesis = NULL,
                        equivalence = NULL,
                        p_adjust = NULL,
@@ -351,7 +338,7 @@ avg_slopes <- function(model,
     # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
     # should probably not be nested too deeply in the call stack since we eval.parent() (not sure about this)
     scall <- rlang::enquo(newdata)
-    newdata <- sanitize_newdata_call(scall, newdata, model)
+    newdata <- sanitize_newdata_call(scall, newdata, model, by = by)
 
 
     # Bootstrap
